==> google_cloud_service_control-1.3.1-py2.py3-none-any.whl: google/cloud/servicecontrol_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .services.quota_controller import QuotaControllerClient
from .services.quota_controller import QuotaControllerAsyncClient
from .services.service_controller import ServiceControllerClient
from .services.service_controller import ServiceControllerAsyncClient

from .types.check_error import CheckError
from .types.distribution import Distribution
from .types.http_request import HttpRequest
from .types.log_entry import LogEntry
from .types.log_entry import LogEntryOperation
from .types.log_entry import LogEntrySourceLocation
from .types.metric_value import MetricValue
from .types.metric_value import MetricValueSet
from .types.operation import Operation
from .types.quota_controller import AllocateQuotaRequest
from .types.quota_controller import AllocateQuotaResponse
from .types.quota_controller import QuotaError
from .types.quota_controller import QuotaOperation
from .types.service_controller import CheckRequest
from .types.service_controller import CheckResponse
from .types.service_controller import ReportRequest
from .types.service_controller import ReportResponse

__all__ = (
    "QuotaControllerAsyncClient",
    "ServiceControllerAsyncClient",
    "AllocateQuotaRequest",
    "AllocateQuotaResponse",
    "CheckError",
    "CheckRequest",
    "CheckResponse",
    "Distribution",
    "HttpRequest",
    "LogEntry",
    "LogEntryOperation",
    "LogEntrySourceLocation",
    "MetricValue",
    "MetricValueSet",
    "Operation",
    "QuotaControllerClient",
    "QuotaError",
    "QuotaOperation",
    "ReportRequest",
    "ReportResponse",
    "ServiceControllerClient",
)

==> google_cloud_service_control-1.4.1-py2.py3-none-any.whl: google/cloud/servicecontrol_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .services.quota_controller import QuotaControllerAsyncClient, QuotaControllerClient
from .services.service_controller import (
    ServiceControllerAsyncClient,
    ServiceControllerClient,
)
from .types.check_error import CheckError
from .types.distribution import Distribution
from .types.http_request import HttpRequest
from .types.log_entry import LogEntry, LogEntryOperation, LogEntrySourceLocation
from .types.metric_value import MetricValue, MetricValueSet
from .types.operation import Operation
from .types.quota_controller import (
    AllocateQuotaRequest,
    AllocateQuotaResponse,
    QuotaError,
    QuotaOperation,
)
from .types.service_controller import (
    CheckRequest,
    CheckResponse,
    ReportRequest,
    ReportResponse,
)

__all__ = (
    "QuotaControllerAsyncClient",
    "ServiceControllerAsyncClient",
    "AllocateQuotaRequest",
    "AllocateQuotaResponse",
    "CheckError",
    "CheckRequest",
    "CheckResponse",
    "Distribution",
    "HttpRequest",
    "LogEntry",
    "LogEntryOperation",
    "LogEntrySourceLocation",
    "MetricValue",
    "MetricValueSet",
    "Operation",
    "QuotaControllerClient",
    "QuotaError",
    "QuotaOperation",
    "ReportRequest",
    "ReportResponse",
    "ServiceControllerClient",
)
